customData property
Arbitrary data forwarded to InspectableProperty.setValue on each edit.
Useful for passing context such as an undo stack or a transaction object.
Implementation
final Object? customData;
Arbitrary data forwarded to InspectableProperty.setValue on each edit.
Useful for passing context such as an undo stack or a transaction object.
final Object? customData;