owners property
The Inspectable objects whose property is being edited.
All owners are updated simultaneously when the user commits a change.
Implementation
final List<Inspectable> owners;
The Inspectable objects whose property is being edited.
All owners are updated simultaneously when the user commits a change.
final List<Inspectable> owners;