The (min, max) clamp range, or null when there is no range restriction.
null
Set to null when multiple owners are selected, since the slider only makes sense for a single-object selection.
(double, double)? clamp;