nullable property

bool nullable
getter/setter pair

Whether the property accepts null as a valid enum value.

When true, an extra empty DropdownMenuItem is added at the end of the dropdown list.

Implementation

bool nullable = false;