readOnlyProperty property
Whether any owner has marked this property as read-only.
When true, user input is ignored even though the field is visible.
Implementation
bool readOnlyProperty = false;
Whether any owner has marked this property as read-only.
When true, user input is ignored even though the field is visible.
bool readOnlyProperty = false;