nullableProperty property
Whether empty input should be written as null rather than ''.
Derived from InspectableProperty.nullable across all owners.
Implementation
bool nullableProperty = true;
Whether empty input should be written as null rather than ''.
Derived from InspectableProperty.nullable across all owners.
bool nullableProperty = true;