removeProperty method

void removeProperty(
  1. String name
)

Removes the property with the given name from properties.

Does nothing if no property with that name exists.

Implementation

void removeProperty(String name) {
  properties.removeWhere((element) => element.name==name,);
}