readOnly property
Whether this property should be rendered as read-only in the inspector.
When true, the editor widget is displayed but user interaction is
disabled.
Implementation
bool readOnly;
Whether this property should be rendered as read-only in the inspector.
When true, the editor widget is displayed but user interaction is
disabled.
bool readOnly;