type property

Type get type

The Dart Type of this property, derived from the generic parameter T.

Used by Inspector to select the correct EditorBuilder from its editors map without requiring a concrete value to inspect.

Implementation

Type get type => T;