values property

List<T> Function()? values
getter/setter pair

Returns the exhaustive list of allowed values for this property.

Required for Enum properties so the editor can populate its DropdownButton. May also be used by custom editors for any type.

Implementation

List<T> Function()? values;