customData property
Arbitrary data passed through to each editor and ultimately to InspectableProperty.setValue on every change.
Implementation
final Object? customData;
Arbitrary data passed through to each editor and ultimately to InspectableProperty.setValue on every change.
final Object? customData;