getObjectPropertySet method

Set<(String, Type)> getObjectPropertySet(
  1. Inspectable obj
)

Returns a set of (name, runtimeType) pairs for all properties on obj.

The runtime type is obtained by reading the current value, so the set only includes properties with non-null values. This set is used to compute the intersection of common properties when Inspector.objects contains multiple objects.

Implementation

Set<(String, Type)> getObjectPropertySet(Inspectable obj) {
  Set<(String, Type)> toReturn = {};

  for (var property in obj.properties) {
    dynamic t = property.getValue(obj);
    toReturn.add((property.name, t.runtimeType));
  }

  return toReturn;
}