properties property
The list of inspectable property descriptors for this object.
Populate this list — usually inside the class constructor — with one InspectableProperty per field you want the Inspector to display.
Implementation
List<InspectableProperty> properties = [];