removeProperty method
Removes the property with the given name from properties.
Does nothing if no property with that name exists.
Implementation
void removeProperty(String name) {
properties.removeWhere((element) => element.name==name,);
}
Removes the property with the given name from properties.
Does nothing if no property with that name exists.
void removeProperty(String name) {
properties.removeWhere((element) => element.name==name,);
}