getValue property
Reads the current value of this property from obj.
Returns null when the value has not been set or when the property is
nullable and currently holds null.
Implementation
T? Function(Inspectable obj) getValue;
Reads the current value of this property from obj.
Returns null when the value has not been set or when the property is
nullable and currently holds null.
T? Function(Inspectable obj) getValue;