objects property
Snapshot of the objects list from the previous build.
Compared against Inspector.objects each build to detect when the selection has changed, which clears the keys cache.
Implementation
late List<Inspectable> objects;
Snapshot of the objects list from the previous build.
Compared against Inspector.objects each build to detect when the selection has changed, which clears the keys cache.
late List<Inspectable> objects;